@@ -4,6 +4,8 @@
 import json
 import traceback
 
+import yaml
+
 from twisted.internet.defer import inlineCallbacks, maybeDeferred
 from twisted.python import log
 
@@ -175,8 +177,8 @@ class CollectionHandler(BaseHandler):
         """
         data = json.loads(self.request.body)
         d = maybeDeferred(self.collection.create, None, data)
-        # TODO: better output once .create returns better things
-        d.addCallback(lambda object_id: self.write_object({"id": object_id}))
+        # the result of .create is (object_id, obj)
+        d.addCallback(lambda result: self.write_object(result[1]))
         d.addErrback(self.catch_err, 400, CollectionUsageError)
         d.addErrback(self.raise_err, 500, "Failed to create object.")
         return d
@@ -297,6 +299,15 @@ def compose(f, g):
     return h
 
 
+def read_yaml_config(config_file, optional=True):
+    """Parse an (usually) optional YAML config file."""
+    if optional and config_file is None:
+        return {}
+    with file(config_file, 'r') as stream:
+        # Assume we get a dict out of this.
+        return yaml.safe_load(stream)
+
+
 class ApiApplication(Application):
     """
     An API for a set of collections and adhoc additional methods.
@@ -311,6 +322,9 @@ class ApiApplication(Application):
         routes = self._build_routes()
         Application.__init__(self, routes, **settings)
 
+    def get_config_settings(self, config_file=None):
+        return read_yaml_config(config_file)
+
     def _build_routes(self):
         """
         Build up routes for handlers from collections and
